


#include "h/p18f14k22.h"

#include "h/Affichages.h"
#include "h/I2C.h"
#include "h/SPI.h"
#include "h/MAX7219.h"
#include "h/Parametres.h"
#include "h/Utilitaires.h"



const rom unsigned char ArrondisValeursPositives[16] = {0, 1, 1, 2, 3, 3, 4, 4, 5, 6, 6, 7, 8, 8, 9, 9};
const rom unsigned char ArrondisValeursNegatives[16] = {9, 9, 8, 8, 7, 7, 6, 6, 5, 4, 4, 3, 2, 2, 1, 0};


unsigned char g_Affichages[4] = {0x00};

unsigned char g_Points[8] = {0x00};

const rom unsigned char AffichagePointsUniques[8] = {0x80, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x01};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRuban[8] = {0xFF, 0x7F, 0x3F, 0x1F, 0x0F, 0x07, 0x03, 0x01};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */

const rom unsigned char AffichagePointsRubanAleatoires0[8] = {0xFF, 0xBF, 0x3F, 0x2F, 0x0F, 0x07, 0x06, 0x04};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires1[8] = {0xFF, 0x7F, 0x6F, 0x4F, 0x0F, 0x0E, 0x0A, 0x02};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires2[8] = {0xFF, 0xBF, 0xAF, 0x8F, 0x0F, 0x07, 0x03, 0x01};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires3[8] = {0xFF, 0xBF, 0x3F, 0x2F, 0x0F, 0x0D, 0x0C, 0x08};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */

const rom unsigned char AffichagePointsRubanAleatoires4[8] = {0xFF, 0xF7, 0xF3, 0xF1, 0xD1, 0xD0, 0xC0, 0x40};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires5[8] = {0xFF, 0x7F, 0x3F, 0x37, 0x35, 0x31, 0x11, 0x10};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires6[8] = {0xFF, 0x7F, 0x77, 0x67, 0x47, 0x07, 0x06, 0x02};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */
const rom unsigned char AffichagePointsRubanAleatoires7[8] = {0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x07, 0x05, 0x01};	/* Portions : 7, 6, 5, 4, 3, 2, 1, 0 */

void Scrutations(void)
{
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_0, g_Affichages[0], MAX7219_DIGIT_0, g_Points[0]);	/* Heures, dizaines et points, premier huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_1, g_Affichages[1], MAX7219_DIGIT_1, g_Points[1]);	/* Heures, units et points, deuxime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_2, g_Affichages[2], MAX7219_DIGIT_2, g_Points[2]);	/* Minutes, dizaines et points, troisime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_3, g_Affichages[3], MAX7219_DIGIT_3, g_Points[3]);	/* Minutes, units et points, quatrime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_4, 0x00, MAX7219_DIGIT_4, g_Points[4]);	/* Points, cinquime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_5, 0x00, MAX7219_DIGIT_5, g_Points[5]);	/* Points, sixime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_6, 0x00, MAX7219_DIGIT_6, g_Points[6]);	/* Points, septime huitime */
	EcrireOctetsMAX7219_1_2(MAX7219_DIGIT_7, 0x00, MAX7219_DIGIT_7, g_Points[7]);	/* Points, huitime huitime */
}

void PreparerHeure(unsigned char Heures, unsigned char Minutes, unsigned char Secondes, unsigned char StyleTour, unsigned char DeuxPoints)
{
	unsigned char TamponMasquageTour;

	if(StyleTour <= STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF)
	{
		ChangerSecondes(0, Secondes, StyleTour);	/* Allumage des LED des secondes selon
		le style voulu */
		TamponMasquageTour = AFFICHAGE_MASQUE_TOUR;	/* Allumage des 12 LED des
		secondes  l'extrieur, qui servent de dlimiteurs */
	}
	else
	{
		ChangerSecondes(1, Secondes, StyleTour);	/* Extinction des LED des secondes */
		TamponMasquageTour = 0x00;	/* Extinction des 12 LED des secondes  l'extrieur, qui
		servent de dlimiteurs */	
	}

	if(Heures < 10)
	{
		g_Affichages[0] = (TamponMasquageTour | 0x00);	/* Suppression du zro de
		gauche du chiffre des heures */
	}
	else
	{
		g_Affichages[0] = (TamponMasquageTour | ConvertirPourAffichage((Heures / 10) + 0x30));
	}

	g_Affichages[1] = (TamponMasquageTour | ConvertirPourAffichage((Heures % 10) + 0x30));
	g_Affichages[2] = (TamponMasquageTour | ConvertirPourAffichage((Minutes / 10) + 0x30));
	g_Affichages[3] = (TamponMasquageTour | ConvertirPourAffichage((Minutes % 10) + 0x30));
			
	if(DeuxPoints == 0)
	{
		g_Points[7] = (~AFFICHAGE_MASQUE_DEUX_POINTS & g_Points[7]);	/* Extinction des deux points qui
		sparent les chiffres des heures et des minutes */
	}
	else
	{
		g_Points[7] = (AFFICHAGE_MASQUE_DEUX_POINTS | g_Points[7]);	/* Allumage des deux points qui
		sparent les chiffres des heures de ceux des minutes */
	}
}

void PreparerDate(unsigned char Jours, unsigned char Mois)
{
	ChangerSecondes(1, 0, 0x00);	/* Extinction des LED des secondes */

	if(Jours < 10)
	{
		g_Affichages[0] = 0x00;	/* Suppression du zro de
		gauche du chiffre des jours */
	}
	else
	{
		g_Affichages[0] = ConvertirPourAffichage((Jours / 10) + 0x30);
	}

	g_Affichages[1] = ConvertirPourAffichage((Jours % 10) + 0x30);	/* Jours, units */

	if(Mois < 10)
	{
		g_Affichages[2] = 0x00;	/* Mois, dizaines. */
	}
	else
	{
		g_Affichages[2] = ConvertirPourAffichage((Mois / 10) + 0x30);	/* Mois, dizaines. */
	}

	g_Affichages[3] = ConvertirPourAffichage((Mois % 10) + 0x30);	/* Mois, units. */

	g_Points[7] = (AFFICHAGE_MASQUE_POINT | g_Points[7]);	/* Allumage du point qui
	spare les chiffres des jours de ceux des mois */
}

void PreparerTemperature(unsigned char Entiere, unsigned char Decimale, unsigned char AffichageContour)
{
	ChangerSecondes(1, 0, 0x00);

	if(AffichageContour == 1)
	{
		g_Points[0] = 0xFF;
		g_Points[1] = 0xFF; 
		g_Points[2] = 0x00; 
		g_Points[3] = 0x00; 
		g_Points[4] = 0x00; 
		g_Points[5] = 0xE0;
		g_Points[6] = 0xFF;
		g_Points[7] = 0x0F;
	}
	else if(AffichageContour == 2)
	{
		g_Points[0] = 0x00;
		g_Points[1] = 0x80; 
		g_Points[2] = 0xFF; 
		g_Points[3] = 0xFF; 
		g_Points[4] = 0xFF; 
		g_Points[5] = 0x3F;
		g_Points[6] = 0x00;
		g_Points[7] = 0x00;
	}

	if(Entiere >= 0x80)	/* Si le bit de signe est  un, la temprature est ngative */
	{
		g_Affichages[0] = ConvertirPourAffichage('-');
	}
	else if(Entiere >= 10)	/* Si le bit de signe n'est pas  un mais que la temprature s'crit sur deux chiffres */
	{
		g_Affichages[0] = ConvertirPourAffichage((Entiere / 10) + 0x30);
	}
	else	/* Si le bit de signe n'est pas  un et que la temprature s'crit sur un seul chiffre */	
	{
		g_Affichages[0] = ConvertirPourAffichage(' ');	/* Aucun affichage du chiffre zro de gauche */
	}
	g_Affichages[1] = ConvertirPourAffichage((Entiere % 10) + 0x30);
	g_Affichages[2] = ConvertirPourAffichage(((Decimale >> 4) / 1.6) + 0x30);
	g_Affichages[3] = ConvertirPourAffichage('');
	
	g_Points[7] = (AFFICHAGE_MASQUE_VIRGULE | g_Points[7]);
}

unsigned char ConvertirPourAffichage(unsigned char Valeur)
{
	switch(Valeur)
	{
		case '0' :
		{
			return 0x7E;
			break;
		}
		case '1' :
		{
			return 0x30;
			break;
		}
		case '2' :
		{
			return 0x6D;
			break;
		}
		case '3' :
		{
			return 0x79;
			break;
		}
		case '4' :
		{
			return 0x33;
			break;
		}
		case '5' :
		{
			return 0x5B;
			break;
		}
		case '6' :
		{
			return 0x5F;
			break;
		}
		case '7' :
		{
			return 0x70;
			break;
		}
		case '8' :
		{
			return 0x7F;
			break;
		}
		case '9' :
		{
			return 0x7B;
			break;
		}
		case ' ' :
		{
			return 0x00;
			break;
		}
		case '' :
		{
			return 0x63;
			break;
		}
		case 'A' :
		{
			return 0x77;
			break;
		}
		case '-' :
		{
			return 0x01;
			break;
		}
		default :
		{
			return 0x00;
			break;
		}
	}
}

void ChangerSecondes(unsigned char Extinction, unsigned char Secondes, unsigned char Style)
{
	if(Extinction == 0)
	{
		if(Secondes >= 56)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0xFF;
				g_Points[7] = AffichagePointsRubanAleatoires7[63 - Secondes];
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = AffichagePointsUniques[63 - Secondes];
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF; 
				g_Points[6] = 0xFF; 
				g_Points[7] = AffichagePointsRuban[63 - Secondes];
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 48)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0xFF;
				g_Points[1] = AffichagePointsRubanAleatoires6[55 - Secondes]; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0xFF;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = AffichagePointsUniques[55 - Secondes];
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = AffichagePointsRuban[55 - Secondes];
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 40)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = AffichagePointsRubanAleatoires5[47 - Secondes];
				g_Points[1] = 0x00; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0xFF;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = AffichagePointsUniques[47 - Secondes];  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = 0xFF; 
				g_Points[5] = AffichagePointsRuban[47 - Secondes];  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 32)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0xFF; 
				g_Points[3] = AffichagePointsRubanAleatoires4[39 - Secondes]; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0xFF;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = AffichagePointsUniques[39 - Secondes]; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0xFF; 
				g_Points[4] = AffichagePointsRuban[39 - Secondes]; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 24)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0xFF; 
				g_Points[5] = 0xFF;  
				g_Points[6] = AffichagePointsRubanAleatoires3[31 - Secondes];
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = AffichagePointsUniques[31 - Secondes]; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = 0xFF; 
				g_Points[3] = AffichagePointsRuban[31 - Secondes]; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 16)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0xFF; 
				g_Points[3] = 0x00; 
				g_Points[4] = AffichagePointsRubanAleatoires2[23 - Secondes]; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = AffichagePointsUniques[23 - Secondes]; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = 0xFF; 
				g_Points[2] = AffichagePointsRuban[23 - Secondes]; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else if(Secondes >= 8)
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = AffichagePointsRubanAleatoires1[15 - Secondes]; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0xFF;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = 0x00;
				g_Points[1] = AffichagePointsUniques[15 - Secondes]; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = 0xFF;
				g_Points[1] = AffichagePointsRuban[15 - Secondes]; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}
		else
		{
			if((Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_NEGATIF) || (Style == STYLE_RUBAN_PSEUDO_ALEATOIRE_POSITIF))
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = AffichagePointsRubanAleatoires0[7 - Secondes];  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x00)
			{
				g_Points[0] = AffichagePointsUniques[7 - Secondes];
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else if((Style & 0x02) == 0x02)
			{
				g_Points[0] = AffichagePointsRuban[7 - Secondes];
				g_Points[1] = 0x00; 
				g_Points[2] = 0x00; 
				g_Points[3] = 0x00; 
				g_Points[4] = 0x00; 
				g_Points[5] = 0x00;  
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
			else
			{
				g_Points[0] = 0x00;
				g_Points[1] = 0x00;
				g_Points[2] = 0x00;
				g_Points[3] = 0x00;
				g_Points[4] = 0x00;
				g_Points[5] = 0x00;
				g_Points[6] = 0x00;
				g_Points[7] = 0x00;
			}
		}

		if((Style & 0x01) == 0x00)
		{
			g_Points[0] = (~g_Points[0]);
			g_Points[1] = (~g_Points[1]); 
			g_Points[2] = (~g_Points[2]); 
			g_Points[3] = (~g_Points[3]); 
			g_Points[4] = (~g_Points[4]); 
			g_Points[5] = (~g_Points[5]);  
			g_Points[6] = (~g_Points[6]);
			g_Points[7] = ((~g_Points[7]) & AFFICHAGE_MASQUE_SYMBOLES);	/* Ne change pas l'tat des symboles du milieu */
		}
	}
	else
	{
		g_Points[0] = 0x00;
		g_Points[1] = 0x00;
		g_Points[2] = 0x00;
		g_Points[3] = 0x00;
		g_Points[4] = 0x00;
		g_Points[5] = 0x00;
		g_Points[6] = 0x00;
		g_Points[7] = 0x00;
	}
}

void AfficherUneTemperature(unsigned char Endroit, unsigned char L1, unsigned char L2)
{
	unsigned char MasquageIndicationsEndroits = 0x00;

	switch(Endroit)
	{
		case ENDROIT_AFFICHAGE_TEMPERATURE :
		{
			MasquageIndicationsEndroits = 0xFF;	/* Si l'affichage de la temprature
												concerne l'intrieur,
												les 12 LED du tour de l'horloge sont teintes. */

			break;
		}

		default :
		{
			MasquageIndicationsEndroits = 0xFF;	/* Si l'affichage de la temprature
												ne concerne pas l'intrieur,
												les 12 LED du tour de l'horloge sont teintes. */

			break;
		}
	}

	if((L1 > 0x79) && (L1 < 0xF6))	/* Si la temprature mesure est infrieure  - 9,9 C */ 
	{
		/* Affichage de l'indication  b  */

		//Write(ADRESSE_EXPANSEUR_DE_PORTS, (MasquageIndicationsEndroits & 0xFF));
	
		g_Affichages[3] = 0x00;
		g_Affichages[2] = 0x7A;
		g_Affichages[1] = 0x00;
		g_Affichages[0] = 0x00;
	}
	else
	{
		if((L1 < 0x80) && (L1 > 0x63))	/* Si la temprature mesure est suprieure  99,9 C */
		{
			/* Affichage de l'indication  H  */

			//Write(ADRESSE_EXPANSEUR_DE_PORTS, (MasquageIndicationsEndroits & 0xFF));
	
			g_Affichages[3] = 0x00;
			g_Affichages[2] = 0x6B;
			g_Affichages[1] = 0x00;
			g_Affichages[0] = 0x00;
		}
		else
		{
			/* Affichage du symbole virgule -  ,  */
			//Write(ADRESSE_EXPANSEUR_DE_PORTS, (MasquageIndicationsEndroits & 0xD7));
			if(L1 < 0x80)
			{
				if(L1 <= 9)
				{
					g_Affichages[3] = 0x00;
				}
				else
				{
					g_Affichages[3] = ConvertirPourAffichage(0x30 + (L1 / 10));
				}
				g_Affichages[2] = ConvertirPourAffichage(0x30 + (L1 % 10));
		
				g_Affichages[1] = ConvertirPourAffichage(0x30 + ((ArrondisValeursPositives[(L2 >> 4)]) % 10));
			}
			else
			{
				L1 = (128 - (0x7F & L1));
		
				/* Affichage du symbole  Moins  -  -  */
				g_Affichages[3] = ConvertirPourAffichage('-');
		
				g_Affichages[2] = ConvertirPourAffichage(0x30 + (L1 - 1));
		
				g_Affichages[1] = ConvertirPourAffichage(0x30 + ((ArrondisValeursNegatives[(L2 >> 4)]) % 10));
			}
			g_Affichages[0] = ConvertirPourAffichage('');
		}	
	}
}

void RecupererHeure(unsigned char AdresseHorlogeTempsReel, unsigned char *Heures, unsigned char *Minutes, unsigned char *Secondes)
{
	unsigned char Heures_Local;
	unsigned char Minutes_Local;
	unsigned char Secondes_Local;
	
	Read16nouvelle(AdresseHorlogeTempsReel, 0x01, (AdresseHorlogeTempsReel | 0x01), &Minutes_Local, &Heures_Local);
	Secondes_Local = Read16court(0xD0, 0x00, 0xD1);

	Heures_Local &= 0x3F;
	Minutes_Local &= 0x7F;
	Secondes_Local &= 0x7F;

	*Heures = BCDVersOctet(Heures_Local);
	*Minutes = BCDVersOctet(Minutes_Local);
	*Secondes = BCDVersOctet(Secondes_Local);
}


