


#include <p18f14k22.h>

#include "h/MemorisationsEEPROM.h"
#include "h/MAX7219.h"
#include "h/Parametres.h"
#include "h/Utilitaires.h"



unsigned char EERead(unsigned char Adresse)
{
	EECON1bits.EEPGD = 0;
	EECON1bits.CFGS = 0;
	EEADR = Adresse;
	EECON1bits.RD = 1;

	return EEDATA;
}

unsigned char EEWrite(unsigned char Adresse, unsigned char Donnee)
{
	EEADR = Adresse;
	EEDATA = Donnee;
	EECON1bits.EEPGD = 0;
	EECON1bits.CFGS = 0;
	EECON1bits.WREN = 1;
	INTCONbits.GIE = 0;
	EECON2 = 0x55;
	EECON2 = 0xAA;
	EECON1bits.WR = 1;
	INTCONbits.GIE = 1;
	while(EECON1bits.WR);
	EECON1bits.WREN = 0;
}

void RecupererExtremes(int *Minimale, int *Maximale)
{
	unsigned char L0;
	unsigned char L1;

	L1 = EERead(ADRESSE_MINIMUM);
	L0 = EERead(ADRESSE_MINIMUM + 1);

	*Minimale = OctetsVersEntier(L1, L0);

	L1 = EERead(ADRESSE_MAXIMUM);
	L0 = EERead(ADRESSE_MAXIMUM + 1);

	*Maximale = OctetsVersEntier(L1, L0);
}

void EnregistrerExtremes(int Minimum, int Maximum)
{
	unsigned char L0;
	unsigned char L1;

	EntierVersOctets(Minimum, &L1, &L0);

	EEWrite(ADRESSE_MINIMUM, L1);
	EEWrite((ADRESSE_MINIMUM + 1), L0);

	EntierVersOctets(Maximum, &L1, &L0);

	EEWrite(ADRESSE_MAXIMUM, L1);
	EEWrite((ADRESSE_MAXIMUM + 1), L0);
}

unsigned char RecupererParametresEEPROM(unsigned char *Fonction, unsigned char *Style, unsigned char *Progressif, unsigned char *Luminosite)
{
	unsigned char TamponFonction;
	unsigned char TamponStyle;
	unsigned char TamponProgressif;
	unsigned char TamponLuminosite;

	unsigned char NombreParametresValides = 0;

	TamponFonction = EERead(ADRESSE_FONCTION);
	if((TamponFonction >= FONCTION_AFFICHAGE_HEURE) && (TamponFonction <= FONCTION_AFFICHAGE_VARIABLE)) 
	{
		*Fonction = TamponFonction;
		NombreParametresValides = 1;	
	}
	else
	{
		*Fonction = PARAMETRE_PAR_DEFAUT_FONCTION;
		EEWrite(ADRESSE_FONCTION, PARAMETRE_PAR_DEFAUT_FONCTION);
	}

	TamponStyle = EERead(ADRESSE_STYLE);
	if((TamponStyle >= STYLE_POINTS_NEGATIF) && (TamponStyle <= STYLE_RUBAN_ETEINT_DEUX_POINTS_FIXES)) 
	{
		*Style = TamponStyle;
		NombreParametresValides++;
	}
	else
	{
		*Style = PARAMETRE_PAR_DEFAUT_STYLE;
		EEWrite(ADRESSE_STYLE, PARAMETRE_PAR_DEFAUT_STYLE);
	}

	TamponProgressif = EERead(ADRESSE_PROGRESSIF);
	if((TamponProgressif == PROGRESSIF_DESACTIVE) || (TamponProgressif == PROGRESSIF_ACTIVE)) 
	{
		*Progressif = TamponProgressif;
		NombreParametresValides++;
	}
	else
	{
		*Style = PARAMETRE_PAR_DEFAUT_PROGRESSIF;
		EEWrite(ADRESSE_STYLE, PARAMETRE_PAR_DEFAUT_PROGRESSIF);
	}

	TamponLuminosite = EERead(ADRESSE_LUMINOSITE);
	if((TamponLuminosite >= MAX_7219_LUMINOSITE_MINIMALE) && (TamponLuminosite <= MAX_7219_LUMINOSITE_MAXIMALE)) 
	{
		*Luminosite = TamponLuminosite;
		NombreParametresValides++;
	}
	else
	{
		*Luminosite = PARAMETRE_PAR_DEFAUT_LUMINOSITE;
		EEWrite(ADRESSE_LUMINOSITE, PARAMETRE_PAR_DEFAUT_LUMINOSITE);
	}

	return NombreParametresValides;
}
