


#include "h/p18f14k22.h"

#include <i2c.h>

#include "h/Affichages.h"
#include "h/I2C.h"
#include "h/SPI.h"
#include "h/MemorisationsEEPROM.h"
#include "h/Thermometre.h"
#include "h/MAX7219.h"
#include "h/Parametres.h"
#include "h/Utilitaires.h"


/* Bits de configuration du microcontrleur, voir Help -> Topics -> PIC18 Config Settings */

/* #pragma config FOSC = IRC
#pragma config PLLEN = OFF
#pragma config PCLKEN = OFF
#pragma config FCMEN = OFF
#pragma config IESO = OFF
#pragma config PWRTEN = OFF
#pragma config BOREN = OFF
#pragma config BORV = 19
#pragma config WDTEN = OFF
#pragma config WDTPS = 2
#pragma config HFOFST = ON
#pragma config MCLRE = OFF
#pragma config STVREN = OFF 
#pragma config LVP = OFF
#pragma config BBSIZ = OFF 
#pragma config XINST = OFF */
 


unsigned char g_Jours = 0;
unsigned char g_Mois = 0;

unsigned char g_Heures = 0;
unsigned char g_Minutes = 0;
unsigned char g_Secondes = 0;

unsigned char g_Fonction;

unsigned char g_Style;
unsigned char g_Progressif;

unsigned char g_Luminosite;

int g_Minimale = 0;
int g_Maximale = 0;



void main(void)
{
	INTCONbits.GIE = 0;	/* Desactivation gnrale des interruptions */

	OSCCON = 0xFF;

	OSCTUNE = 0x00;

	CCP1CON = 0;

	/* Configuration des entres relies  l'ADC du microcontrleur en tant qu'entres numriques */ 
	ANSEL = 0x00;
	ANSELH = 0x00; 
   
	T1CON = 0b10000000;

	DIRECTION_32_KHZ_DS3231 = 1;
	DIRECTION_INT_SQW_DS3231 = 1;
	
	DIRECTION_LOAD_MAX7219 = 0;
	DIRECTION_DIN_MAX7219 = 0;
	DIRECTION_CLK_MAX7219 = 0;
	
	DIRECTION_BOUTON_1 = 1;
	DIRECTION_BOUTON_2 = 1;
	DIRECTION_BOUTON_3 = 1;
	DIRECTION_BOUTON_4 = 1;

	DIRECTION_I2C_SDA = 1;
	DIRECTION_I2C_SCL = 1;
	
	BROCHE_LOAD_MAX7219 = 1;
	BROCHE_DIN_MAX7219 = 0;
	BROCHE_CLK_MAX7219 = 0;

	EcrireOctetsMAX7219_1_2(MAX7219_DISPLAY_TEST, 0x01, MAX7219_DISPLAY_TEST, 0x01);	/* Dispaly Test : placement en  Display Test Mode  */

	INTCONbits.PEIE = 0;	/* Activation des interruptions des aux priphriques */
	INTCONbits.INT0IE = 1;	/* Activation de l'interruption de  la broche  RA0 - INT  */
	INTCONbits.RABIE = 1;	/* Activation de l'interruption de au changement d'tat des broches du port A et du port B */
	PIE1bits.TMR1IE = 0;	/* Desactivation des interruptions des au module du TIMER1 */
	INTCON2bits.INTEDG0 = 0;	/* Configuration du dclenchement des interruptions des  la broche  RB0 - INT0  sur front descendant */
	INTCON2bits.RABIP = 0;	/* Configuration de l'interruption de au changement d'tat des broches du port A et du port B en
	basse priorit par rapport  l'interruption de  la broche  RA0 - INT   */

	IOCA = (INTERRUPTION_MASQUE_BOUTON_2 | INTERRUPTION_MASQUE_BOUTON_1);
	IOCB = (INTERRUPTION_MASQUE_BOUTON_4 | INTERRUPTION_MASQUE_BOUTON_3);

	OpenI2C(MASTER, SLEW_OFF);

	SSPADD = 39;
	
	Delai(3000);

	RecupererHeure(ADRESSE_HORLOGE_TEMPS_REEL, &g_Heures, &g_Minutes, &g_Secondes);
	RecupererExtremes(&g_Minimale, &g_Maximale);

	RecupererParametresEEPROM(&g_Fonction, &g_Style, &g_Progressif, &g_Luminosite);

	ConfigurerUnCapteur(ADRESSE_CAPTEUR_TEMPERATURE);

	Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x01, (OctetVersBCD(g_Minutes)));
	Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x0E, 0x00);

	T1CONbits.TMR1ON = 0;	/* Dsactivation du module du TIMER1 */

	INTCONbits.GIE = 1;	/* Activation gnrale des interruptions */

	EcrireOctetsMAX7219_1_2(MAX7219_SHUTDOWN, 0x00, MAX7219_SHUTDOWN, 0x00);	/* Shutdown : placement en  Shutdown Mode  */
	
	EcrireOctetsMAX7219_1_2(MAX7219_DECODE_MODE, 0x00, MAX7219_DECODE_MODE, 0x00);	/* Aucun dcodage pour tous les afficheurs, les
			octets de donnes envoys dfinissent l'affichage */
	
	EcrireOctetsMAX7219_1_2(MAX7219_SCAN_LIMIT, 0x04, MAX7219_SCAN_LIMIT, 0x07);	/* Pilotage des 4 affichages pour les
	chiffres et des 8 affichages pour les secondes ainsi que les symboles de sparations */
					
	EcrireOctetsMAX7219_1_2(MAX7219_INTENSITY, g_Luminosite, MAX7219_INTENSITY, g_Luminosite);	/* Rglage de l'intensit du
	courant dlivr dans les diodes,
			utilisant un rapport cyclique programmable initialis  3 / 32.
			0x00 : 1 / 32, minimum,
			0x0F : 31 / 32, maximum. */
	
	EcrireOctetsMAX7219_1_2(MAX7219_DISPLAY_TEST, 0x00, MAX7219_DISPLAY_TEST, 0x00);	/* Dispaly Test : placement en  Normal Operation  */

	EcrireOctetsMAX7219_1_2(MAX7219_SHUTDOWN, 0x01, MAX7219_SHUTDOWN, 0x01);	/* Shutdown : placement en  Normal Operation  */

	Scrutations();

	while(1)
	{
		
	}
}

#pragma interrupt InterruptHandler   
void InterruptHandler (void)
{
	unsigned char k;
	unsigned char l;

	unsigned char TamponMasquageTour;

	unsigned char T1 = 0;
	unsigned char T2 = 0;

	unsigned char CompteurAppuiLong;

	unsigned char LuminositePrecedente;

	static unsigned char IndicationAffHeureAct = 0;
	static unsigned char IndicationAffDateAct = 0;

	static unsigned char IndicationReglageHeure = 0;
	static unsigned char IndicationReglageDate = 0;

	static unsigned char IndicationAffTemperatureAct = 0;

	static unsigned char IndicationAffichageExtremes = 0;

	static unsigned char AffichageTemperature = 0;

	static unsigned char InhibitionModeVariable = 0;

	if(INTCONbits.INT0IE && INTCONbits.INT0IF)	/* Si le signal carr a prsent un front descendant */
	{	
		if(g_Secondes < 59)
		{
			g_Secondes++;	
		}
		else
		{
			g_Secondes = 0;

			IndicationReglageHeure = 0;
			IndicationReglageDate = 0;

			IndicationAffichageExtremes = 0;
	
			if(g_Minutes < 59)
			{
				g_Minutes++;
			}
			else
			{
				g_Minutes = 0;

				if(g_Heures < 23)
				{
					g_Heures++;
				}
				else
				{
					g_Heures = 0;
				}

				/* Enregistrement des valeurs minimale et maximale de la temprature toutes les heures */
				EnregistrerExtremes(g_Minimale, g_Maximale);
			}
		}

		switch(g_Fonction)
		{
			case FONCTION_AFFICHAGE_HEURE :
			{
				if(g_Progressif == PROGRESSIF_DESACTIVE)
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				else if(g_Progressif == PROGRESSIF_ACTIVE)
				{
					for(l = 0; l < g_Secondes; l++)
					{
						PreparerHeure(g_Heures, g_Minutes, l, g_Style, 1);
						Scrutations();
						Delai(30000 / (g_Secondes + 1));
					}
				}
				else
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				
				if(g_Style != STYLE_RUBAN_ETEINT_DEUX_POINTS_FIXES)
				{
					while((BROCHE_BOUTON_1 == 1) && (BROCHE_BOUTON_2 == 1) && (BROCHE_BOUTON_3 == 1) && (BROCHE_BOUTON_4 == 1) && (BROCHE_INT_SQW_DS3231 == 0));

					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 0);
					Scrutations();
				}

				IndicationAffHeureAct = 1;
				IndicationAffDateAct = 0;

				AffichageTemperature = 0;
							
				break;
			}

			case FONCTION_AFFICHAGE_DATE :
			{
				Read16nouvelle(0xD0, 0x04, 0xD1, &g_Jours, &g_Mois);

				g_Jours &= 0x3F;
				g_Mois &= 0x7F;
			
				g_Jours = BCDVersOctet(g_Jours);
				g_Mois = BCDVersOctet(g_Mois);

				PreparerDate(g_Jours, g_Mois);
				Scrutations();

				IndicationAffHeureAct = 0;
				IndicationAffDateAct = 1;
				IndicationAffTemperatureAct = 0;

				AffichageTemperature = 0;

				break;
			}

			case FONCTION_AFFICHAGE_TEMPERATURE :
			{
				Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
				if((T1 == 0) && (T2 == 0))
				{
					Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
				}

				MaximumMinimum(OctetsVersEntier(T1, T2), &g_Minimale, &g_Maximale, 0);

				if(AffichageTemperature == 1)
				{	
					EntierVersOctets(g_Maximale, &T1, &T2);
				}
				else if(AffichageTemperature == 2)
				{
					EntierVersOctets(g_Minimale, &T1, &T2);
				}

				PreparerTemperature(T1, T2, AffichageTemperature);
				Scrutations();

				IndicationAffHeureAct = 0;
				IndicationAffDateAct = 0;
				IndicationAffTemperatureAct = 1;
				
				break;
			}

			case FONCTION_AFFICHAGE_VARIABLE :
			{
				if((InhibitionModeVariable == 0) && ((IndicationReglageDate == 1) || (IndicationAffichageExtremes == 1) || ((IndicationReglageHeure == 0) && ((g_Secondes == 10) || (g_Secondes == 11) || (g_Secondes == 12) || (g_Secondes == 15) || (g_Secondes == 20) || (g_Secondes == 21) || (g_Secondes == 22) || (g_Secondes == 40) || (g_Secondes == 41) || (g_Secondes == 42) || (g_Secondes == 45) || (g_Secondes == 50) || (g_Secondes == 51) || (g_Secondes == 52)))))
				{
					if((IndicationAffichageExtremes == 0) && ((IndicationReglageDate == 1) || (g_Secondes == 15) || (g_Secondes == 45)))
					{
						Read16nouvelle(0xD0, 0x04, 0xD1, &g_Jours, &g_Mois);
		
						g_Jours &= 0x3F;
						g_Mois &= 0x7F;
					
						g_Jours = BCDVersOctet(g_Jours);
						g_Mois = BCDVersOctet(g_Mois);
		
						PreparerDate(g_Jours, g_Mois);
						Scrutations();

						IndicationAffDateAct = 1;
						IndicationAffTemperatureAct = 0;

						AffichageTemperature = 0;
					}
					else
					{
						Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
						if((T1 == 0) && (T2 == 0))
						{
							Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
						}

						if(AffichageTemperature == 1)
						{
							MaximumMinimum(OctetsVersEntier(T1, T2), &g_Minimale, &g_Maximale, 0);	
							EntierVersOctets(g_Maximale, &T1, &T2);
						}
						else if(AffichageTemperature == 2)
						{
							MaximumMinimum(OctetsVersEntier(T1, T2), &g_Minimale, &g_Maximale, 0);
							EntierVersOctets(g_Minimale, &T1, &T2);
						}

						PreparerTemperature(T1, T2, AffichageTemperature);
						Scrutations();

						IndicationAffDateAct = 0;
						IndicationAffTemperatureAct = 1;
					}
					IndicationAffHeureAct = 0;
				}
				else
				{
					if(g_Progressif == PROGRESSIF_DESACTIVE)
					{
						PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
						Scrutations();
					}
					else if(g_Progressif == PROGRESSIF_ACTIVE)
					{
						for(l = 0; l < g_Secondes; l++)
						{
							PreparerHeure(g_Heures, g_Minutes, l, g_Style, 1);
							Scrutations();
							Delai(30000 / (g_Secondes + 1));
						}
					}
					else
					{
						PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
						Scrutations();
					}
					
					if(g_Style != STYLE_RUBAN_ETEINT_DEUX_POINTS_FIXES)
					{
						while((BROCHE_BOUTON_1 == 1) && (BROCHE_BOUTON_2 == 1) && (BROCHE_BOUTON_3 == 1) && (BROCHE_BOUTON_4 == 1) && (BROCHE_INT_SQW_DS3231 == 0));
	
						PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 0);
						Scrutations();
					}

					if(InhibitionModeVariable > 0)
					{
						InhibitionModeVariable--;
					}

					IndicationAffHeureAct = 1;
					IndicationAffDateAct = 0;
					IndicationAffTemperatureAct = 0;

					AffichageTemperature = 0;
				}

				break;
			}

			default :
			{
				if(g_Progressif == PROGRESSIF_DESACTIVE)
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				else if(g_Progressif == PROGRESSIF_ACTIVE)
				{
					for(l = 0; l < g_Secondes; l++)
					{
						PreparerHeure(g_Heures, g_Minutes, l, g_Style, 1);
						Scrutations();
						Delai(30000 / (g_Secondes + 1));
					}
				}
				else
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				
				if(g_Style != STYLE_RUBAN_ETEINT_DEUX_POINTS_FIXES)
				{
					while((BROCHE_BOUTON_1 == 1) && (BROCHE_BOUTON_2 == 1) && (BROCHE_BOUTON_3 == 1) && (BROCHE_BOUTON_4 == 1) && (BROCHE_INT_SQW_DS3231 == 0));

					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 0);
					Scrutations();
				}

				IndicationAffHeureAct = 1;
				IndicationAffDateAct = 0;
				IndicationAffTemperatureAct = 0;

				AffichageTemperature = 0;

				break;
			}
		}

		if(IndicationAffTemperatureAct == 0)
		{
			Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
			if((T1 == 0) && (T2 == 0))
			{
				Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
			}

			MaximumMinimum(OctetsVersEntier(T1, T2), &g_Minimale, &g_Maximale, 0);
		}

		INTCONbits.INT0IF = 0;
	}

	if((INTCONbits.RABIE == 1) && (INTCONbits.RABIF == 1))	/* Si la modification
	d'un des boutons-poussoirs est signale */	
	{
		Delai(300);

		INTCONbits.RABIE = 0;
		if(BROCHE_BOUTON_1 == 0)	/* Si le bouton-poussoir des jours et
		des heures est appuy */
		{
			if(IndicationAffHeureAct == 1)
			{
				if(g_Heures < 23)
				{
					g_Heures++;
				}
				else
				{
					g_Heures = 0;
				}

				Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x02, (OctetVersBCD(g_Heures)));	/* Actualisation du chiffre
																	des heures de l'horloge temps rel  la
																	valeur qui correspond au nouveau rglage */

				if(g_Progressif == PROGRESSIF_DESACTIVE)
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				else if(g_Progressif == PROGRESSIF_ACTIVE)
				{
					for(l = 0; l < g_Secondes; l++)
					{
						PreparerHeure(g_Heures, g_Minutes, l, g_Style, 1);
						Scrutations();
						Delai(30000 / (g_Secondes + 1));
					}
				}
				else
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}

				if(g_Fonction == FONCTION_AFFICHAGE_VARIABLE)
				{
					IndicationReglageHeure = 1;
				}
			}
			else if(IndicationAffDateAct == 1)
			{
				if((((g_Mois == 1) || (g_Mois == 3) || (g_Mois == 5) || (g_Mois == 7) || (g_Mois == 8) || (g_Mois == 10) || (g_Mois == 12)) && (g_Jours < 31)) || ((g_Mois == 2) && (g_Jours < 29)) || (((g_Mois == 4) || (g_Mois == 6) || (g_Mois == 9) || (g_Mois == 11)) && (g_Jours < 30)))
				{
					g_Jours++;
				}
				else
				{
					g_Jours = 1;
				}

				Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x04, (OctetVersBCD(g_Jours)));	/* Actualisation du chiffre
																	des jours de l'horloge temps rel  la
																	valeur qui correspond au nouveau rglage */

				PreparerDate(g_Jours, g_Mois);
				Scrutations();

				if(g_Fonction == FONCTION_AFFICHAGE_VARIABLE)
				{
					IndicationReglageDate = 1;
				}
			}
			else if(IndicationAffTemperatureAct == 1)
			{
				if(AffichageTemperature < 2)
				{
					AffichageTemperature++;
					IndicationAffichageExtremes = 1;

					EnregistrerExtremes(g_Minimale, g_Maximale);
				}
				else
				{
					AffichageTemperature = 0;

					IndicationAffichageExtremes = 0;
				}
			}
		}
		else if(BROCHE_BOUTON_2 == 0)	/* Si le bouton-poussoir des mois et
		des minutes est appuy */
		{
			if(IndicationAffHeureAct == 1)
			{
				IndicationReglageHeure = 0;
				IndicationReglageDate = 0;

				if(g_Minutes < 59)
				{
					g_Minutes++;
				}
				else
				{
					g_Minutes = 0;
				}
				g_Secondes = 0;

				ChangerSecondes(0, 0, g_Style);

				Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x00, 0x00);	/* Actualisation du chiffre
																		des secondes de l'horloge temps
																		rel  0 */

				Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x01, (OctetVersBCD(g_Minutes)));	/* Actualisation du chiffre
																							des minutes de l'horloge temps rel  la
																							valeur qui corrspond au nouveau rglage */

				if(g_Progressif == PROGRESSIF_DESACTIVE)
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
				else if(g_Progressif == PROGRESSIF_ACTIVE)
				{
					for(l = 0; l < g_Secondes; l++)
					{
						PreparerHeure(g_Heures, g_Minutes, l, g_Style, 1);
						Scrutations();
						Delai(30000 / (g_Secondes + 1));
					}
				}
				else
				{
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();
				}
			}
			else if(IndicationAffDateAct == 1)
			{
				if(g_Mois < 12)
				{
					g_Mois++;
				}
				else
				{
					g_Mois = 1;
				}


				Write16court(ADRESSE_HORLOGE_TEMPS_REEL, 0x05, (OctetVersBCD(g_Mois)));	/* Actualisation du chiffre
																	des mois de l'horloge temps rel  la
																	valeur qui correspond au nouveau rglage */

				PreparerDate(g_Jours, g_Mois);
				Scrutations();

				if(g_Fonction == FONCTION_AFFICHAGE_VARIABLE)
				{
					IndicationReglageDate = 1;
				}
			}
			else if(IndicationAffTemperatureAct == 1)
			{
				Read16nouvelle(ADRESSE_CAPTEUR_TEMPERATURE, 0x00, (ADRESSE_CAPTEUR_TEMPERATURE | 0x01), &T1, &T2);
				MaximumMinimum(OctetsVersEntier(T1, T2), &g_Minimale, &g_Maximale, 1);
				IndicationAffichageExtremes = 1;

				EnregistrerExtremes(g_Minimale, g_Maximale);
			}
		}
		else if(BROCHE_BOUTON_3 == 0)	/* Si le bouton-poussoir de changement de
		fonction et de luminosite est appuy */
		{
			CompteurAppuiLong = 0;

			while((CompteurAppuiLong < 100) && (BROCHE_BOUTON_3 == 0))	/* Tant que le comptage d'appui long n'est
			pas termin et tant que le bouton-poussoir de changement de fonction et de
			luminosit est appuy */
			{
				CompteurAppuiLong++;
				Delai(300);
			}
			if(CompteurAppuiLong < 100)
			{
				if(g_Fonction < FONCTION_AFFICHAGE_VARIABLE)
				{
					g_Fonction++;
				}
				else
				{
					g_Fonction = FONCTION_AFFICHAGE_HEURE;
				}
	
				if(g_Fonction == FONCTION_AFFICHAGE_VARIABLE)
				{
					InhibitionModeVariable = 3;
				}
				else
				{
					IndicationReglageHeure = 0;
					IndicationReglageDate = 0;
				}
	
				EEWrite(ADRESSE_FONCTION, g_Fonction);
			}
			else
			{
				k = 1;
				LuminositePrecedente = g_Luminosite;
				do
				{
					InhibitionModeVariable = 3;

					if(k == 0)
					{
						if(g_Luminosite > MAX_7219_LUMINOSITE_MINIMALE)
						{
							g_Luminosite--;
						}
						else
						{
							g_Luminosite = (MAX_7219_LUMINOSITE_MINIMALE + 1);
							k = 1;
						}
					}
					else if(k == 1)
					{
						if(g_Luminosite < MAX_7219_LUMINOSITE_MAXIMALE)
						{
							g_Luminosite++;
						}
						else
						{
							g_Luminosite = (MAX_7219_LUMINOSITE_MAXIMALE - 1);
							k = 0;
						}
					}
					else
					{
						k = 1;
					}

					EcrireOctetsMAX7219_1_2(MAX7219_INTENSITY, g_Luminosite, MAX7219_INTENSITY, g_Luminosite);	/* Rglage de l'intensit du
					courant dlivr dans les diodes,
					utilisant un rapport cyclique programmable.
					0x00 : 1 / 32, minimum,
					0x0F : 31 / 32, maximum. */

					RecupererHeure(ADRESSE_HORLOGE_TEMPS_REEL, &g_Heures, &g_Minutes, &g_Secondes);
	
					PreparerHeure(g_Heures, g_Minutes, g_Secondes, g_Style, 1);
					Scrutations();

					Delai(30000);
				}
				while(BROCHE_BOUTON_3 == 0);	/* Tant que le bouton-poussoir de changement de
				fonction et de luminosite est appuy */

				if(g_Luminosite != LuminositePrecedente)
				{
					EEWrite(ADRESSE_LUMINOSITE, g_Luminosite);
				}
			}
		}
		else if(BROCHE_BOUTON_4 == 0)	/* Si le bouton-poussoir de changement de
		style et de mode progressif est appuy */
		{
			CompteurAppuiLong = 0;

			while((CompteurAppuiLong < 100) && (BROCHE_BOUTON_4 == 0))	/* Tant que le comptage d'appui long n'est
			pas termin et tant que le bouton-poussoir de changement de style et de
			mode progressif est appuy */
			{
				CompteurAppuiLong++;
				Delai(300);
			}
			if(CompteurAppuiLong < 100)
			{
				InhibitionModeVariable = 3;

				if(g_Style < STYLE_RUBAN_ETEINT_DEUX_POINTS_FIXES)
				{
					g_Style++;
				}
				else
				{
					g_Style = STYLE_POINTS_NEGATIF;
				}

				EEWrite(ADRESSE_STYLE, g_Style);
			}
			else
			{
				InhibitionModeVariable = 3;

				if(g_Progressif == PROGRESSIF_DESACTIVE)
				{
					g_Progressif = PROGRESSIF_ACTIVE;
				}
				else if(g_Progressif == PROGRESSIF_ACTIVE)
				{
					g_Progressif = PROGRESSIF_DESACTIVE;
				}
				else
				{
					g_Progressif = PROGRESSIF_DESACTIVE;
				}

				EEWrite(ADRESSE_PROGRESSIF, g_Progressif);

				Delai(30000);

				while(BROCHE_BOUTON_4 == 0);	/* Tant que le bouton-poussoir de changement de
		style et de mode progressif est appuy */
			}
		}
		else	/* Si aucun des boutons-poussoirs n'a t appuy */
		{

		}

		INTCONbits.RABIF = 0;
		INTCONbits.RABIE = 1;
	}	
}



#pragma code InterruptVectorHigh = 0x08 
void InterruptVectorHigh(void)
{
    _asm
        goto InterruptHandler
    _endasm
}
 

